@@ -1,6 +1,6 @@
 use strict;
 package CPAN::Reporter;
-our $VERSION = '1.2002'; # VERSION
+our $VERSION = '1.2003'; # VERSION
 
 use Config;
 use Capture::Tiny qw/ capture tee_merged /;
@@ -1480,7 +1480,7 @@ CPAN::Reporter - Adds CPAN Testers reporting to CPAN.pm
 
 =head1 VERSION
 
-version 1.2002
+version 1.2003
 
 =head1 SYNOPSIS
 
@@ -1698,9 +1698,9 @@ progress on the request by the system.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<http://github.com/dagolden/cpan-reporter>
+L<https://github.com/dagolden/cpan-reporter>
 
-  git clone http://github.com/dagolden/cpan-reporter
+  git clone https://github.com/dagolden/cpan-reporter.git
 
 =head1 AUTHOR
 
